@@ -1,9 +1,10 @@
 from __future__ import annotations
 
 import asyncio
+import os
 import signal
 import sys
-from asyncio import StreamReader
+from codecs import StreamReader
 from collections import namedtuple
 from typing import Dict, List, Optional
 
